from enum import Enum


class Purpose(Enum):
    AUTO_LOAN = "AUTO_LOAN"
    HOUSING_LOAN = "HOUSING_LOAN"
    PROPERTY_LOAN = "PROPERTY_LOAN"
    LOAN_AGAINST_SECURITIES = "LOAN_AGAINST_SECURITIES"
    PERSONAL_LOAN = "PERSONAL_LOAN"
    CONSUMER_LOAN = "CONSUMER_LOAN"
    GOLD_LOAN = "GOLD_LOAN"
    EDUCATION_LOAN = "EDUCATION_LOAN"
    LOAN_TO_PROFESSIONAL = "LOAN_TO_PROFESSIONAL"
    CREDIT_CARD = "CREDIT_CARD"
    LEASING = "LEASING"
    OVERDRAFT = "OVERDRAFT"
    TWO_WHEELER_LOAN = "TWO_WHEELER_LOAN"
    NON_FUNDED_CREDIT_FACILITY = "NON_FUNDED_CREDIT_FACILITY"
    LOAN_AGAINST_BANK_DEPOSITS = "LOAN_AGAINST_BANK_DEPOSITS"
    FLEET_CARD = "FLEET_CARD"
    COMMERCIAL_VEHICLE_LOAN = "COMMERCIAL_VEHICLE_LOAN"
    TELCO_WIRELESS = "TELCO_WIRELESS"
    TELCO_BROADBAND = "TELCO_BROADBAND"
    TELCO_LANDLINE = "TELCO_LANDLINE"
    SECURED_CREDIT_CARD = "SECURED_CREDIT_CARD"
    USED_CAR_LOAN = "USED_CAR_LOAN"
    CONSTRUCTION_EQUIPMENT_LOAN = "CONSTRUCTION_EQUIPMENT_LOAN"
    TRACTOR_LOAN = "TRACTOR_LOAN"
    CORPORATE_CREDIT_CARD = "CORPORATE_CREDIT_CARD"
    KISAN_CREDIT_CARD = "KISAN_CREDIT_CARD"
    LOAN_ON_CREDIT_CARD = "LOAN_ON_CREDIT_CARD"
    PRIME_MINISTER_JAAN_DHAN_YOJANA_OVERDRAFT = (
        "PRIME_MINISTER_JAAN_DHAN_YOJANA_OVERDRAFT"
    )
    MUDRA_LOANS = "MUDRA_LOANS"
    MICROFINANCE_BUSINESS_LOAN = "MICROFINANCE_BUSINESS_LOAN"
    MICROFINANCE_PERSONAL_LOAN = "MICROFINANCE_PERSONAL_LOAN"
    MICROFINANCE_HOUSING_LOAN = "MICROFINANCE_HOUSING_LOAN"
    MICROFINANCE_OTHER = "MICROFINANCE_OTHER"
    PRADHAN_MANTRI_AWAS_YOJANA_MAY_CLSS = "PRADHAN_MANTRI_AWAS_YOJANA_MAY_CLSS"
    BUSINESS_LOAN_SECURED = "BUSINESS_LOAN_SECURED"
    BUSINESS_LOAN_GENERAL = "BUSINESS_LOAN_GENERAL"
    BUSINESS_LOAN_PRIORITY_SMALL_BUSINESS = "BUSINESS_LOAN_PRIORITY_SMALL_BUSINESS"
    BUSINESS_LOAN_PRIORITY_AGRICULTURE = "BUSINESS_LOAN_PRIORITY_AGRICULTURE"
    BUSINESS_LOAN_PRIORITY_OTHERS = "BUSINESS_LOAN_PRIORITY_OTHERS"
    BUSINESS_NON_FUNDED_CREDIT_GENERAL = "BUSINESS_NON_FUNDED_CREDIT_GENERAL"
    BUSINESS_NON_FUNDED_CREDIT_PRIORITY_SMALL = (
        "BUSINESS_NON_FUNDED_CREDIT_PRIORITY_SMALL"
    )
    BUSINESS_NON_FUNDED_CREDIT_PRIORITY_AGRICULTURE = (
        "BUSINESS_NON_FUNDED_CREDIT_PRIORITY_AGRICULTURE"
    )
    BUSINESS_NON_FUNDED_CREDIT_PRIORITY_OTHERS = (
        "BUSINESS_NON_FUNDED_CREDIT_PRIORITY_OTHERS"
    )
    BUSINESS_LOAN_AGAINST_BANK_DEPOSITS = "BUSINESS_LOAN_AGAINST_BANK_DEPOSITS"
    BUSINESS_LOAN_UNSECURED = "BUSINESS_LOAN_UNSECURED"
    MICROFINANCE_DETAILED_REPORT = "MICROFINANCE_DETAILED_REPORT"
    SUMMARY_REPORT = "SUMMARY_REPORT"
    LOCATE_PLUS_FOR_INSURANCE = "LOCATE_PLUS_FOR_INSURANCE"
    ACCOUNT_REVIEW = "ACCOUNT_REVIEW"
    RETRO_ENQUIRY = "RETRO_ENQUIRY"
    LOCATE_PLUS = "LOCATE_PLUS"
    ADVISER_LIABILITY = "ADVISER_LIABILITY"
    SECURED = "SECURED"
    UNSECURED = "UNSECURED"
    OTHER = "OTHER"


class State(Enum):
    ANDHRA_PRADESH = "ANDHRA_PRADESH"
    ARUNACHAL_PRADESH = "ARUNACHAL_PRADESH"
    ASSAM = "ASSAM"
    BIHAR = "BIHAR"
    CHATTISGARH = "CHATTISGARH"
    GOA = "GOA"
    GUJARAT = "GUJARAT"
    HARYANA = "HARYANA"
    HIMACHAL_PRADESH = "HIMACHAL_PRADESH"
    JAMMU_KASHMIR = "JAMMU_KASHMIR"
    JHARKHAND = "JHARKHAND"
    KARNATAKA = "KARNATAKA"
    KERALA = "KERALA"
    MADHYA_PRADESH = "MADHYA_PRADESH"
    MAHARASHTRA = "MAHARASHTRA"
    MANIPUR = "MANIPUR"
    MEGHALAYA = "MEGHALAYA"
    MIZORAM = "MIZORAM"
    NAGALAND = "NAGALAND"
    ORISSA = "ORISSA"
    PUNJAB = "PUNJAB"
    RAJASTHAN = "RAJASTHAN"
    SIKKIM = "SIKKIM"
    TAMIL_NADU = "TAMIL_NADU"
    TELANGANA = "TELANGANA"
    TRIPURA = "TRIPURA"
    UTTAR_PRADESH = "UTTAR_PRADESH"
    UTTARANCHAL = "UTTARANCHAL"
    WEST_BENGAL = "WEST_BENGAL"
    ANDAMAN_NICOBAR_ISLANDS = "ANDAMAN_NICOBAR_ISLANDS"
    CHANDIGARH = "CHANDIGARH"
    DADRA_NAGAR_HAVELI = "DADRA_NAGAR_HAVELI"
    DAMAN_DIU = "DAMAN_DIU"
    DELHI = "DELHI"
    LAKSHADWEEP = "LAKSHADWEEP"
    PONDICHERRY = "PONDICHERRY"
    APO = "APO"


class ScoreType(Enum):
    NO_SCORE = "NO_SCORE"
    CIBILTUSCR_ONLY = "CIBILTUSCR_ONLY"
    PLSCORE_ONLY = "PLSCORE_ONLY"
    CIBILTUSCR_PLSCORE = "CIBILTUSCR_PLSCORE"
    CIBILTUSC2_ONLY = "CIBILTUSC2_ONLY"
    CIBILTUSC2_PLSCORE = "CIBILTUSC2_PLSCORE"
    CIBILTUSC3_ONLY = "CIBILTUSC3_ONLY"
    CIBILTUSC3_PLSCORE = "CIBILTUSC3_PLSCORE"
    CIBILTUIE1_CIBILTUSCR = "CIBILTUIE1_CIBILTUSCR"
    CIBILTUIE1_CIBILTUSC2 = "CIBILTUIE1_CIBILTUSC2"
    CIBILTUIE1_CIBILTUSC3 = "CIBILTUIE1_CIBILTUSC3"
    CIBILTUIE1_CIBILTUSCR_PLSCORE = "CIBILTUIE1_CIBILTUSCR_PLSCORE"
    CIBILTUIE1_CIBILTUSC2_PLSCORE = "CIBILTUIE1_CIBILTUSC2_PLSCORE"
    CIBILTUIE1_CIBILTUSC3_PLSCORE = "CIBILTUIE1_CIBILTUSC3_PLSCORE"


class Gender(Enum):
    MALE = "MALE"
    FEMALE = "FEMALE"
    TRANSGENDER = "TRANSGENDER"


class IdentityType(Enum):
    PAN_CARD = "PAN_CARD"
    PASSPORT = "PASSPORT"
    VOTER_ID = "VOTER_ID"
    DRIVING_LICENSE = "DRIVING_LICENSE"
    RATION_CARD = "RATION_CARD"
    UID = "UID"


class PhoneNumberType(Enum):
    HOME = "HOME"
    OFFICE = "OFFICE"
    MOBILE = "MOBILE"
    NOT_CLASSIFIED = "NOT_CLASSIFIED"


class AddressType(Enum):
    PERMANENT = "PERMANENT"
    RESIDENCE = "RESIDENCE"
    OFFICE = "OFFICE"
    NOT_CATEGORIZED = "NOT_CATEGORIZED"


class ResidenceType(Enum):
    OWNED = "OWNED"
    RENTED = "RENTED"


class RelationType(Enum):
    FATHER = "FATHER"
    HUSBAND = "HUSBAND"
    MOTHER = "MOTHER"
    SON = "SON"
    DAUGHTER = "DAUGHTER"
    WIFE = "WIFE"
    BROTHER = "BROTHER"
    MOTHER_IN_LAW = "MOTHER_IN_LAW"
    FATHER_IN_LAW = "FATHER_IN_LAW"
    DAUGHTER_IN_LAW = "DAUGHTER_IN_LAW"
    SISTER_IN_LAW = "SISTER_IN_LAW"
    SON_IN_LAW = "SON_IN_LAW"
    BROTHER_IN_LAW = "BROTHER_IN_LAW"
    OTHER = "OTHER"
