from enum import Enum


class EnquiryReason(Enum):
    AGRICULTURE_LOAN = "AGRICULTURE_LOAN"
    AUTO_LOAN = "AUTO_LOAN"
    BUSINESS_LOAN = "BUSINESS_LOAN"
    COMMERCIAL_VEHICLE_LOAN = "COMMERCIAL_VEHICLE_LOAN"
    CONSTRUCTION_EQUIPMENT_LOAN = "CONSTRUCTION_EQUIPMENT_LOAN"
    CONSUMER_LOAN = "CONSUMER_LOAN"
    CREDIT_CARD = "CREDIT_CARD"
    EDUCATION_LOAN = "EDUCATION_LOAN"
    LEASING = "LEASING"
    LOAN_AGAINST_COLLATERAL = "LOAN_AGAINST_COLLATERAL"
    MICROFINANCE = "MICROFINANCE"
    NON_FUNDED_CREDIT = "NON_FUNDED_CREDIT"
    PERSONAL_LOAN = "PERSONAL_LOAN"
    PROPERTY_LOAN = "PROPERTY_LOAN"
    TELECOM = "TELECOM"
    TWO_THREE_WHEELER_LOAN = "TWO_THREE_WHEELER_LOAN"
    WORKING_CAPITAL_LOAN = "WORKING_CAPITAL_LOAN"
    OTHERS = "OTHERS"


class FinancePurpose(Enum):
    AGRICULTURAL_MACHINERY = "AGRICULTURAL_MACHINERY"
    ANIMAL_HUSBANDRY = "ANIMAL_HUSBANDRY"
    AQUACULTURE = "AQUACULTURE"
    BIOGAS_PLANT = "BIOGAS_PLANT"
    CROP_LOAN = "CROP_LOAN"
    HORTICULTURE = "HORTICULTURE"
    IRRIGATION_SYSTEM = "IRRIGATION_SYSTEM"
    NEW_CAR = "NEW_CAR"
    OVERDRAFT_AGAINST_CAR = "OVERDRAFT_AGAINST_CAR"
    USED_CAR = "USED_CAR"
    GENERAL_BUSINESS = "GENERAL_BUSINESS"
    SMALL_MEDIUM_BUSINESS = "SMALL_MEDIUM_BUSINESS"
    PROFESSIONALS = "PROFESSIONALS"
    TRADE = "TRADE"
    BUS = "BUS"
    TEMPO = "TEMPO"
    TIPPER = "TIPPER"
    TRUCK = "TRUCK"
    TRACTOR = "TRACTOR"
    EXCAVATORS = "EXCAVATORS"
    FORKLIFT = "FORKLIFT"
    WHEEL_LOADERS = "WHEEL_LOADERS"
    CONSUMER_SEARCH = "CONSUMER_SEARCH"
    CREDIT_CARD = "CREDIT_CARD"
    FLEET_CARD = "FLEET_CARD"
    SECURED_CREDIT_CARD = "SECURED_CREDIT_CARD"
    CORPORATE_CREDIT_CARD = "CORPORATE_CREDIT_CARD"
    WORKING_EXECUTIVES = "WORKING_EXECUTIVES"
    STUDY_ABROAD = "STUDY_ABROAD"
    STUDY_INDIA = "STUDY_INDIA"
    LEASING = "LEASING"
    BANK_DEPOSITS = "BANK_DEPOSITS"
    GOLD = "GOLD"
    GOVT_BONDS = "GOVT_BONDS"
    SHARES_MUTUAL_FUNDS = "SHARES_MUTUAL_FUNDS"
    BUSINESS_LOAN = "BUSINESS_LOAN"
    HOUSING_LOAN = "HOUSING_LOAN"
    PERSONAL_LOAN = "PERSONAL_LOAN"
    AGRICULTURE = "AGRICULTURE"
    GENERAL_CREDIT = "GENERAL_CREDIT"
    SMALL_BUSINESS = "SMALL_BUSINESS"
    COMPUTERS = "COMPUTERS"
    CONSUMER_DURABLES = "CONSUMER_DURABLES"
    MARRIAGE_RELIGIOUS_CEREMONIES = "MARRIAGE_RELIGIOUS_CEREMONIES"
    TRAVEL = "TRAVEL"
    BALANCE_TRANSFER = "BALANCE_TRANSFER"
    HOME_IMPROVEMENT = "HOME_IMPROVEMENT"
    LAND = "LAND"
    LEASE_RENTAL_DISCOUNTING = "LEASE_RENTAL_DISCOUNTING"
    LOAN_AGAINST_PROPERTY = "LOAN_AGAINST_PROPERTY"
    NEW_HOME = "NEW_HOME"
    OFFICE_PREMISES = "OFFICE_PREMISES"
    UNDER_CONSTRUCTION = "UNDER_CONSTRUCTION"
    BROADBAND = "BROADBAND"
    LANDLINE = "LANDLINE"
    MOBILE = "MOBILE"
    THREE_WHEELER = "THREE_WHEELER"
    TWO_WHEELER = "TWO_WHEELER"
    CASH_CREDIT_FACILITY = "CASH_CREDIT_FACILITY"
    OVERDRAFT = "OVERDRAFT"
    TERM_LOAN = "TERM_LOAN"
    OTHERS = "OTHERS"


class Gender(Enum):
    MALE = "MALE"
    FEMALE = "FEMALE"
    TRANSGENDER = "TRANSGENDER"


class PhoneNumberType(Enum):
    HOME = "HOME"
    OFFICE = "OFFICE"
    MOBILE = "MOBILE"
    NOT_CLASSIFIED = "NOT_CLASSIFIED"


class MaritalStatus(Enum):
    SINGLE = "SINGLE"
    MARRIED = "MARRIED"
    DIVORCED = "DIVORCED"
    WIDOW_WIDOWER = "WIDOW_WIDOWER"


class EmploymentStatus(Enum):
    SALARIED = "SALARIED"
    NON_SALARIED = "NON_SALARIED"
    SELF_EMPLOYED = "SELF_EMPLOYED"
    SELF_EMPLOYED_PROFESSIONAL = "SELF_EMPLOYED_PROFESSIONAL"
    UNEMPLOYED = "UNEMPLOYED"


class State(Enum):
    ANDHRA_PRADESH = "ANDHRA_PRADESH"
    ARUNACHAL_PRADESH = "ARUNACHAL_PRADESH"
    ASSAM = "ASSAM"
    BIHAR = "BIHAR"
    GOA = "GOA"
    GUJARAT = "GUJARAT"
    HARYANA = "HARYANA"
    HIMACHAL_PRADESH = "HIMACHAL_PRADESH"
    JAMMU_KASHMIR = "JAMMU_KASHMIR"
    JHARKHAND = "JHARKHAND"
    KARNATAKA = "KARNATAKA"
    KERALA = "KERALA"
    MADHYA_PRADESH = "MADHYA_PRADESH"
    MAHARASHTRA = "MAHARASHTRA"
    MANIPUR = "MANIPUR"
    MEGHALAYA = "MEGHALAYA"
    MIZORAM = "MIZORAM"
    NAGALAND = "NAGALAND"
    ORISSA = "ORISSA"
    PUNJAB = "PUNJAB"
    RAJASTHAN = "RAJASTHAN"
    SIKKIM = "SIKKIM"
    TAMIL_NADU = "TAMIL_NADU"
    TELANGANA = "TELANGANA"
    TRIPURA = "TRIPURA"
    UTTAR_PRADESH = "UTTAR_PRADESH"
    UTTARANCHAL = "UTTARANCHAL"
    WEST_BENGAL = "WEST_BENGAL"
    ANDAMAN_NICOBAR_ISLANDS = "ANDAMAN_NICOBAR_ISLANDS"
    CHANDIGARH = "CHANDIGARH"
    CHATTISGARH = "CHATTISGARH"
    DADRA_NAGAR_HAVELI = "DADRA_NAGAR_HAVELI"
    DAMAN_DIU = "DAMAN_DIU"
    DELHI = "DELHI"
    LAKSHADWEEP = "LAKSHADWEEP"
    PONDICHERRY = "PONDICHERRY"
